====================
django-autohide-help
====================

django-autohide-help is a jQuery_ plugin packaged as a Django_ app for easy
installation. It's a plugin that allows frontend developers to hide help blocks
generated by `crispy forms`_.

Installation
============

Install using pip::

    pip install django-autohide-help

After adding ``autohide_help`` to ``INSTALLED_APPS``, ``autohide-help.js`` will
be avalable at ``{{ STATIC_URL }}js/autohide-help.js``.

If you are using RequireJS_, you can add ``autohide-help`` to dependencies, as
it is packages with RequireJS support.

If you want to use it via a simple script tag, you can add the script tag as
usual::

    <script src="{{ STATIC_URL}}js/autohide-help.js``"></script>

This plugin requires jQuery (obviously).

Basic usage
===========

Select a form (or forms), and call ``autohideHelp`` on it::

    $('form').autohideHelp()

As user enters the fields the help block is slid out, and slid back in as user
leaves the field.

Using without crispy forms
==========================

Crispy forms are not absolutely required. It is just convenient to use them
since they automatically generate the help blocks.

If you want to use django-autohide-help without the crispy forms, make sure
that your help blocks have an id in the following format: ``help_FIELD_ID``
where ``FIELD_ID`` is the id of the field to which the help block belongs. For
example, if you field has an id of ``id_name``, the help block must have the
id of ``help_id_name``. Future releases of ``django-authide-help`` may make
this configurable.

Reporting bugs
==============

Please report bugs to Bitbucket `issue tracker`_.

.. _jQuery: http://jquery.com/
.. _Django: http://www.djangoproject.com/
.. _crispy forms: http://django-crispy-forms.readthedocs.org/en/d-0/
.. _issue tracker: https://bitbucket.org/brankovukelic/django-autohide-help/issues
